@@ -5,7 +5,7 @@ use strict;
 use Test::Builder;
 use File::Spec;
 use UNIVERSAL::require;
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 my $Test = Test::Builder->new;
 
 sub import {
@@ -35,7 +35,6 @@ sub pm_file_ok {
     my $module = $file;
     $module =~ s!^(blib[/\\])?lib[/\\]!!;
     $module =~ s![/\\]!::!g;
-
     $module =~ s/\.pm$//;
     my $ok = 1;
     $module->use;
@@ -364,4 +363,9 @@ Copyright 2007-2009 by the authors.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+L<Test::LoadAllModules> just handles modules, not script files, but has more
+fine-grained control.
+
 =cut
